@@ -28,7 +28,7 @@ module Specinfra
       def run_command(cmd, opts={})
         cmd = build_command(cmd)
         cmd = add_pre_command(cmd)
-        docker_run!(cmd)
+        docker_run!(cmd, opts)
       end
 
       def build_command(cmd)
@@ -40,13 +40,17 @@ module Specinfra
       end
 
       def send_file(from, to)
-        if @base_image.nil?
-          fail 'Cannot call send_file without docker_image.'
+        if @base_image
+          @images << commit_container if @container
+          @images << current_image.insert_local('localPath' => from, 'outputPath' => to)
+          cleanup_container
+          create_and_start_container
+        elsif @container
+          # This needs Docker >= 1.8
+          @container.archive_in(from, to)
+        else
+          fail 'Cannot call send_file without docker_image or docker_container.'
         end
-
-        @images << current_image.insert_local('localPath' => from, 'outputPath' => to)
-        cleanup_container
-        create_and_start_container
       end
 
       def commit_container
@@ -58,7 +62,7 @@ module Specinfra
       def create_and_start_container
         opts = { 'Image' => current_image.id }
 
-        if current_image.json["Config"]["Cmd"].nil?
+        if current_image.json["Config"]["Cmd"].nil? && current_image.json["Config"]["Entrypoint"].nil?
           opts.merge!({'Cmd' => ['/bin/sh']})
         end
 
@@ -75,6 +79,9 @@ module Specinfra
 
         @container = ::Docker::Container.create(opts)
         @container.start
+        while @container.json['State'].key?('Health') && @container.json['State']['Health']['Status'] == "starting" do
+          sleep 0.5
+        end
       end
 
       def cleanup_container
@@ -87,7 +94,8 @@ module Specinfra
       end
 
       def docker_run!(cmd, opts={})
-        stdout, stderr, status = @container.exec(['/bin/sh', '-c', cmd])
+        opts.merge!(get_config(:docker_container_exec_options) || {})
+        stdout, stderr, status = @container.exec(['/bin/sh', '-c', cmd], opts)
 
         CommandResult.new :stdout => stdout.join, :stderr => stderr.join,
         :exit_status => status
