@@ -16,6 +16,7 @@ require 'specinfra/command/module/service/god'
 require 'specinfra/command/module/service/delegator'
 require 'specinfra/command/module/systemd'
 require 'specinfra/command/module/zfs'
+require 'specinfra/command/module/ss'
 
 # Base
 require 'specinfra/command/base'
@@ -48,7 +49,7 @@ require 'specinfra/command/base/user'
 require 'specinfra/command/base/yumrepo'
 require 'specinfra/command/base/zfs'
 
-# Linux (inhefit Base)
+# Linux (inherit Base)
 require 'specinfra/command/linux'
 require 'specinfra/command/linux/base'
 require 'specinfra/command/linux/base/bridge'
@@ -78,6 +79,7 @@ require 'specinfra/command/esxi/base/package'
 require 'specinfra/command/redhat'
 require 'specinfra/command/redhat/base'
 require 'specinfra/command/redhat/base/file'
+require 'specinfra/command/redhat/base/host'
 require 'specinfra/command/redhat/base/iptables'
 require 'specinfra/command/redhat/base/package'
 require 'specinfra/command/redhat/base/service'
@@ -89,7 +91,9 @@ require 'specinfra/command/redhat/v5/iptables'
 
 # RedHat V7 (inherit RedHat)
 require 'specinfra/command/redhat/v7'
+require 'specinfra/command/redhat/v7/host'
 require 'specinfra/command/redhat/v7/service'
+require 'specinfra/command/redhat/v7/port'
 
 # Fedora (inherit RedhHat)
 require 'specinfra/command/fedora'
@@ -100,12 +104,21 @@ require 'specinfra/command/fedora/base/service'
 require 'specinfra/command/fedora/v15'
 require 'specinfra/command/fedora/v15/service'
 
+# Arista EOS (inherit Fedora)
+require 'specinfra/command/eos'
+require 'specinfra/command/eos/base'
+
+# Amazon Linux (inherit RedHat)
+require 'specinfra/command/amazon'
+require 'specinfra/command/amazon/base'
+
 # AIX (inherit Base)
 require 'specinfra/command/aix'
 require 'specinfra/command/aix/base'
 require 'specinfra/command/aix/base/file'
 require 'specinfra/command/aix/base/group'
 require 'specinfra/command/aix/base/host'
+require 'specinfra/command/aix/base/inventory'
 require 'specinfra/command/aix/base/package'
 require 'specinfra/command/aix/base/port'
 require 'specinfra/command/aix/base/service'
@@ -116,6 +129,7 @@ require 'specinfra/command/alpine'
 require 'specinfra/command/alpine/base'
 require 'specinfra/command/alpine/base/package'
 require 'specinfra/command/alpine/base/process'
+require 'specinfra/command/alpine/base/service'
 
 # Arch (inherit Linux)
 require 'specinfra/command/arch'
@@ -134,9 +148,12 @@ require 'specinfra/command/darwin'
 require 'specinfra/command/darwin/base'
 require 'specinfra/command/darwin/base/file'
 require 'specinfra/command/darwin/base/host'
+require 'specinfra/command/darwin/base/interface'
+require 'specinfra/command/darwin/base/inventory'
 require 'specinfra/command/darwin/base/service'
 require 'specinfra/command/darwin/base/package'
 require 'specinfra/command/darwin/base/port'
+require 'specinfra/command/darwin/base/process'
 require 'specinfra/command/darwin/base/user'
 
 # Debian (inherit Linux)
@@ -149,6 +166,10 @@ require 'specinfra/command/debian/base/service'
 # Debian V8 (inherit Debian)
 require 'specinfra/command/debian/v8'
 require 'specinfra/command/debian/v8/service'
+require 'specinfra/command/debian/v8/port'
+
+# Raspbian (inherit Debian)
+require 'specinfra/command/raspbian'
 
 # Ubuntu (inherit Debian)
 require 'specinfra/command/ubuntu'
@@ -156,6 +177,14 @@ require 'specinfra/command/ubuntu/base'
 require 'specinfra/command/ubuntu/base/ppa'
 require 'specinfra/command/ubuntu/base/service'
 
+# Ubuntu v15.xx (inherit Ubuntu)
+require 'specinfra/command/ubuntu/v15'
+require 'specinfra/command/ubuntu/v15/service'
+
+# Linux Mint (inherit Ubuntu)
+require 'specinfra/command/linuxmint'
+require 'specinfra/command/linuxmint/base'
+
 # Cumulus Networks (inherit Debian)
 require 'specinfra/command/cumulus'
 require 'specinfra/command/cumulus/base'
@@ -191,17 +220,41 @@ require 'specinfra/command/opensuse'
 require 'specinfra/command/opensuse/base'
 require 'specinfra/command/opensuse/base/service'
 
+# SLES (inherit SuSE)
+require 'specinfra/command/sles'
+require 'specinfra/command/sles/base'
+require 'specinfra/command/sles/v12'
+require 'specinfra/command/sles/v12/service'
+
 # FreeBSD (inherit Base)
 require 'specinfra/command/freebsd'
 require 'specinfra/command/freebsd/base'
 require 'specinfra/command/freebsd/base/file'
+require 'specinfra/command/freebsd/base/host'
+require 'specinfra/command/freebsd/base/interface'
+require 'specinfra/command/freebsd/base/inventory'
 require 'specinfra/command/freebsd/base/package'
 require 'specinfra/command/freebsd/base/port'
 require 'specinfra/command/freebsd/base/service'
+require 'specinfra/command/freebsd/base/routing_table'
+require 'specinfra/command/freebsd/base/user'
 
-# FreeBSD V10 (inherit FreeBSD)
-require 'specinfra/command/freebsd/v10'
-require 'specinfra/command/freebsd/v10/package'
+# FreeBSD V6 (inherit FreeBSD)
+require 'specinfra/command/freebsd/v6'
+require 'specinfra/command/freebsd/v6/user'
+require 'specinfra/command/freebsd/v6/package'
+
+# FreeBSD V7 (inherit FreeBSD)
+require 'specinfra/command/freebsd/v7'
+require 'specinfra/command/freebsd/v7/package'
+
+# FreeBSD V8 (inherit FreeBSD)
+require 'specinfra/command/freebsd/v8'
+require 'specinfra/command/freebsd/v8/package'
+
+# FreeBSD V9 (inherit FreeBSD)
+require 'specinfra/command/freebsd/v9'
+require 'specinfra/command/freebsd/v9/package'
 
 # OpenBSD (inherit Base)
 require 'specinfra/command/openbsd'
@@ -210,7 +263,9 @@ require 'specinfra/command/openbsd/base/bond'
 require 'specinfra/command/openbsd/base/bridge'
 require 'specinfra/command/openbsd/base/file'
 require 'specinfra/command/openbsd/base/fstab'
+require 'specinfra/command/openbsd/base/host'
 require 'specinfra/command/openbsd/base/interface'
+require 'specinfra/command/openbsd/base/inventory'
 require 'specinfra/command/openbsd/base/mail_alias'
 require 'specinfra/command/openbsd/base/package'
 require 'specinfra/command/openbsd/base/port'
@@ -218,6 +273,10 @@ require 'specinfra/command/openbsd/base/routing_table'
 require 'specinfra/command/openbsd/base/service'
 require 'specinfra/command/openbsd/base/user'
 
+# OpenBSD >= V5.7 (inherit OpenBSD)
+require 'specinfra/command/openbsd/v57'
+require 'specinfra/command/openbsd/v57/service'
+
 # Solaris (inherit Base)
 require 'specinfra/command/solaris'
 require 'specinfra/command/solaris/base'
@@ -225,8 +284,10 @@ require 'specinfra/command/solaris/base/cron'
 require 'specinfra/command/solaris/base/file'
 require 'specinfra/command/solaris/base/group'
 require 'specinfra/command/solaris/base/host'
+require 'specinfra/command/solaris/base/inventory'
 require 'specinfra/command/solaris/base/ipfilter'
 require 'specinfra/command/solaris/base/ipnat'
+require 'specinfra/command/solaris/base/kernel_module'
 require 'specinfra/command/solaris/base/package'
 require 'specinfra/command/solaris/base/port'
 require 'specinfra/command/solaris/base/service'
@@ -265,3 +326,11 @@ require 'specinfra/command/windows/base/service'
 require 'specinfra/command/windows/base/user'
 require 'specinfra/command/windows/base/registry_key'
 require 'specinfra/command/windows/base/scheduled_task'
+
+# Poky (inherit Linux)
+require 'specinfra/command/poky'
+require 'specinfra/command/poky/base'
+require 'specinfra/command/poky/base/interface'
+require 'specinfra/command/poky/base/inventory'
+require 'specinfra/command/poky/base/package'
+require 'specinfra/command/poky/base/service'
