@@ -2,7 +2,7 @@ class Specinfra::Command::Debian::Base::Service < Specinfra::Command::Linux::Bas
   class << self
     def check_is_enabled(service, level=3)
       # Until everything uses Upstart, this needs an OR.
-      "ls /etc/rc#{level}.d/ | grep -- '^S..#{escape(service)}$' || grep 'start on' /etc/init/#{escape(service)}.conf"
+      "ls /etc/rc#{level}.d/ | grep -- '^S..#{escape(service)}$' || grep '^\s*start on' /etc/init/#{escape(service)}.conf"
     end
 
     def enable(service)
