@@ -12,6 +12,9 @@ module Specinfra
       cpu
       virtualization
       kernel
+      block_device
+      user
+      group
     }
 
     include Enumerable
