@@ -3,7 +3,13 @@ module Specinfra
     class Fqdn < Base
       def get
         cmd = backend.command.get(:get_inventory_fqdn)
-        backend.run_command(cmd).stdout.strip
+        result = backend.run_command(cmd)
+
+        if result.exit_status == 0
+          result.stdout.strip
+        else
+          nil
+        end
       end
     end
   end
